import copy from 'rollup-plugin-copy'
import resolve from '@rollup/plugin-node-resolve'
import babel from '@rollup/plugin-babel'
import svgr from '@svgr/rollup'
import autoExternal from 'rollup-plugin-auto-external'

const url = require('postcss-url')
const postcss = require('rollup-plugin-postcss')

const extensions = ['.js', '.jsx']

export default {
  input: 'src/index.js',
  output: {
    dir: 'dist',
    format: 'esm',
    sourcemap: true,
    preserveModules: true,
    preserveModulesRoot: 'src'
  },
  plugins: [
    postcss({
      plugins: [
        url({
          url: 'inline',
          maxSize: 10,
          fallback: 'copy'
        })]
    }),
    autoExternal(),
    svgr(),
    babel({
      babelHelpers: 'runtime',
      plugins: ['@babel/plugin-transform-runtime'],
      exclude: './node_modules/**',
      extensions
    }),
    resolve(
      {
        mainFields: ['module', 'main', 'jsnext:main', 'browser'],
        extensions
      }
    ),
    copy({
      targets: [
        {
          src: 'src/variables.scss',
          dest: 'dist',
          rename: 'variables.scss'
        },
        {
          src: 'src/assets',
          dest: 'dist'
        },
        {
          src: 'src/hooks',
          dest: 'dist'
        }
      ]
    })
  ],
  external: [
    /@babel\/runtime/,
    'lodash/debounce',
    'lodash/get',
    'lodash/merge',
    'lodash/assign',
    'lodash/find',
    'lodash/isUndefined',
    'lodash/forEach',
    'lodash/isEmpty',
    'lodash/isArray',
    'react-datepicker',
    'react-select/creatable']
}
